;+
;
;
; .. program:: fig_mld
;
; ===========
; fig_mld.pro
; ===========
;
; main POMME project program
;
; - read the 2 mld models :file:`${POMME_ID}/noeddy_mld.nc` and :file:`${POMME_ID}/eddy_mld.nc`
; - read mld insitu data and metadata
; - compute daily mean insitu mld data
; - compute daily mean modeled data in boxes of 1/2 and 1/4 around insitu measurement
; location
; - plot ++
;
; :examples:
;
; ::
;
;   IDL> fig_mld
;   IDL> exit
;
; :uses:
;
; :func:`read_ncdf`
; :func:`julday`
; :func:`pltt`
; :func:`moyenne`
;
; :ref:`init_pom.pro`
; :func:`file_prn_to_mem`
; :func:`file_asc_to_mem`
; :func:`dmean_mld`
; :func:`join_dmean_asc`
;
; :todo:
;
; make it work
;
; consolidate
;
; delta array of 2 : .5 1
;
; :history:
;
; - fplod 20101129T130822Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * add reading of insitu MLD data files and associated
;   * use the right filenames for models
;   * complete header
;
; - fplod 20101125T145638Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * add ReST minimal header
;
; - marina 20101125T130000Z
;
;   * creation draft
;
;
;-
PRO fig_mld
;
compile_opt idl2, strictarrsubs
;
@init_pom
;
; read MLD in model files
mldm = -read_ncdf('mld', 0, 383, /timestep, file=iodir+'eddy_mld.nc',  /nostruct)
mldr = -read_ncdf('mld', 0, 383, /timestep, file=iodir+'noeddy_mld.nc',  /nostruct)
;
time=julday(09,27,2000)+dindgen(jpt)
;
; plot modeled MLD
;openps, 'fig_mld.ps'
;pltt, mldm , box=[-22,-16, 38, 44],  't',  -200,  0, color = 70,  title = 'MLD'
;pltt, mldr , box=[-22,-16, 38, 44],  't',  color = 220,  /ov1d
;closeps
;
; read MLD in insitu files and metafiles
data_asc=file_asc_to_mem()
data_prn=file_prn_to_mem()
data_dmean=dmean_mld(data_prn)
data_insitu=join_dmean_asc(data_dmean,data_asc)
;
; calcul du temps des donnes insitu avec comme 0 le 20000927
time_insitu=julday(1,1,2001) - julday(09,27,2000) - 1 + data_insitu.doy
nt=1
;boucle sur le nombre de donnees:
FOR it = 1, nt DO BEGIN 
; it varie de 0-60 env (nb de donnees campagnes)
   domdef
   ;ici lecture de jt, xlon, ylat : jt varie de 0-383 (nb de sorties
   ;modeles)
   ;jt = 0 : 27 sept 2000
   ;it = 0 : env fev 2001
   ;read, jt, xlon, ylat, mld1, mld2, mld3, mld4, mld5
   jt = 10
   xlon = -20
   ylat = 41
   
   delta = 0.5
   
   mybox = [xlon-delta, xlon+delta, ylat-delta, ylat+delta]
   
   ; ++ verifier que la moyenne est bien faite dans la boite et pas dans tout le domaine
   mldm = reform(read_ncdf('mld', jt, /timestep, file=iodir+'eddy_mld.nc',  /nostruct, box = mybox))
   mldr = reform(read_ncdf('mld', jt, /timestep, file=iodir+'noeddy_mld.nc',  /nostruct, box = mybox))
   
   mymldm = moyenne(mldm, box = mybox, 'xy')
   mymldr = moyenne(mldr, box = mybox, 'xy')
   myvarm = stddev(mldm)
   myvarr = stddev(mldr)
ENDFOR
delta = 1

;
;boucle sur le nombre de donnees:
FOR it = 1, nt DO BEGIN 
; it varie de 0-60 env (nb de donnees campagnes)
   domdef
   ;ici lecture de jt, xlon, ylat : jt varie de 0-383 (nb de sorties
   ;modeles)
   ;jt = 0 : 27 sept 2001
   ;it = 0 : env fev 2001
   ;read, jt, xlon, ylat, mld1, mld2, mld3, mld4, mld5
   jt = 10
   xlon = -20
   ylat = 41
   
   mybox = [xlon-delta, xlon+delta, ylat-delta, ylat+delta]
   
   mldm = reform(read_ncdf('mld', jt, /timestep, file=iodir+'eddy.nc',  /nostruct, box = mybox))
   mldr = reform(read_ncdf('mld', jt, /timestep, file=iodir+'noeddy.nc',  /nostruct, box = mybox))
   
   mymldm1 = moyenne(mldm, box = mybox, 'xy')
   mymldr1 = moyenne(mldr, box = mybox, 'xy')
   myvarm1 = stddev(mldm)
   myvarr1 = stddev(mldr)
ENDFOR
;
;write, jt, xlon, ylat, mld1, mld2, mld3, mld4, mld5, mymldm, mymldr,myvarm, myvarr,mymldm1, mymldr1,myvarm1, myvarr1
END
